wlan_bearer/wlanengine/wlan_symbian/wlanengine_symbian_3.1/inc/wlmserver.h
changeset 14 00032b836e76
parent 13 ab7247ff6ef9
child 17 41a8eba36f74
--- a/wlan_bearer/wlanengine/wlan_symbian/wlanengine_symbian_3.1/inc/wlmserver.h	Fri Mar 19 10:03:22 2010 +0200
+++ b/wlan_bearer/wlanengine/wlan_symbian/wlanengine_symbian_3.1/inc/wlmserver.h	Fri Apr 16 16:56:12 2010 +0300
@@ -16,7 +16,7 @@
 */
 
 /*
-* %version: 52 %
+* %version: 54 %
 */
 
 #ifndef WLMSERVER_H
@@ -981,27 +981,27 @@
         
         /**
          * Handles completion routines of an internal request
          * @param aIndex index to the request that should be completed.
          * @param aStatus status of the completed operation.
          * @param aCompletedWasTriggering value ETrue means that
          *        completed request is the same as the request which
          *        triggered the core operation 
          */
         void CompleteInternalRequest(
-            TUint32 aIndex,
+            const SRequestMapEntry& aRequest,
             core_error_e aStatus,
             TBool aCompletedWasTriggering = ETrue );
 
         /**
          * Handles completion routines of an external request
          * @param aIndex index to the request that should be completed.
          * @param aStatus status of the completed operation.
          * @param aTriggerRequest pointer to the request that triggered core operation
          *        value NULL means that completed request is the same as the request which triggered 
          *        the core operation 
          */
         void CompleteExternalRequest(
-            TUint32 aIndex, 
+            const SRequestMapEntry& aRequest,
             core_error_e aStatus,
             SRequestMapEntry* aTriggerRequest = NULL );
 
@@ -1293,7 +1293,7 @@
         CWlanEapolClient* iEapolClient;
         
         /**
-         * EAPOL callback handler in core.
+         * EAPOL callback handler in core. Not owned by this pointer.
          */        
         abs_wlan_eapol_callback_c* iEapolHandler;
@@ -981,27 +981,27 @@
         /**
          * Handles completion routines of an internal request
-         * @param aIndex index to the request that should be completed.
+         * @param aRequest request that should be completed.
          * @param aStatus status of the completed operation.
          * @param aCompletedWasTriggering value ETrue means that
@@ -981,27 +981,27 @@
         /**
          * Handles completion routines of an external request
-         * @param aIndex index to the request that should be completed.
+         * @param aRequest request that should be completed.
          * @param aStatus status of the completed operation.
          * @param aTriggerRequest pointer to the request that triggered core operation